#ifndef SNAPSHOTSETTINGSDLG_HPP
#define SNAPSHOTSETTINGSDLG_HPP

#include <qcolor.h>

#include "FTPSettings.h"
#include "SnapshotSettings.h"
#include "VideoOptions.h"

class CSnapshotSettingsDlg: public CSnapshotSettings
{
   Q_OBJECT
private:
   struct CVideoOptions *pVOpts;
   CFTPSettings *pFTPSettings;
   QColor TextColor;
   QFont TextFont;
   QString FileFormat;

protected:
   /* overloaded */
   void ClickedOK();
   void ClickedColor();
   void ClickedFont();
   void ClickedFTP();

public:
   CSnapshotSettingsDlg(struct CVideoOptions *opts, QWidget *parent = 0, const char *name = 0);

signals:
   void FTPSettingsUpdated();
};



#endif
